
<img src="logo/soothsayer_square.png" width=200>

_________________________________
#### Description:
*Soothsayer* is a high-level package for (bio-)informatics with various methods for network analysis, hierarchical ensembles of classifiers, feature selection, plotting, and more.

#### Current Version:
*v2023.12.22*

#### Citation:
Espinoza JL, Dupont CL, O’Rourke A, Beyhan S, Morales P, et al. (2021) Predicting antimicrobial mechanism-of-action from transcriptomes: A generalizable explainable artificial intelligence approach. PLOS Computational Biology 17(3): e1008857. [https://doi.org/10.1371/journal.pcbi.1008857](https://doi.org/10.1371/journal.pcbi.1008857)

#### Contact:
Josh L. Espinoza: [jespinoz@jcvi.org](jespinoz@jcvi.org).

_________________________________

#### *Soothsayer* Ecosystem:
* [soothsayer_utils](https://github.com/jolespin/soothsayer_utils) - Utility functions for *Soothsayer*
* [ensemble_networkx](https://github.com/jolespin/ensemble_networkx) - High-level Ensemble Network implementations in Python. Built on top of NetworkX and Pandas.
* [hive_networkx](https://github.com/jolespin/hive_networkx) - High-level Hive plot (Martin Krzywinski et al. 2012) implementations using *Matplotlib* in Python. Built on top of *NetworkX* and *Pandas*.
* [compositional](https://github.com/jolespin/compositional) - Compositional data analysis in Python.

_________________________________

#### Case studies, tutorials and usage:
Documentation will be released upon version 1.0 once API is stabilized.

* [Antimicrobial resistance modeling associated with Espinoza & Dupont et al. 2021](https://github.com/jolespin/projects/blob/main/antimicrobial_resistance_modeling/Espinoza-Dupont_et_al_2021/Notebooks/markdown_version/Espinoza-Dupont_et_al_2021__Supplemental.md)
* [Feature selection using *Clairvoyance* on the Iris dataset with 1000 noise attributes](tutorials/Notebooks/markdown_versions/Denoising_Iris-plus-Noise_with_Clairvoyance/Denoising_Iris-plus-Noise_with_Clairvoyance.md)
* [Multimodal sample-specific perturbation networks and undernutrition modeling from Nabwera & Espinoza et al. 2021](https://github.com/jolespin/projects/blob/main/gambia_gut_undernutrition_microbiome/Nabwera-Espinoza_et_al_2021/Notebooks/markdown_version/Nabwera-Espinoza_et_al_2021.md)

_________________________________

#### Installation:
**Please refer to the [installation manual](install/README.md) for installation details.**  
It will make the installation process *much easier* due to all of the Python and R dependencies. 

* pip: [https://pypi.org/project/soothsayer](https://pypi.org/project/soothsayer)

_________________________________


#### Development:
*Soothsayer* is in a developmental stage.  If you're not sure if your installation is a developmental version, check by running: `import soothsayer as sy; print(sy.__developmental__)`.  It is *highly recommended* to [update to the current version](https://github.com/jolespin/soothsayer/tree/master/install#update-to-the-current-release-recommended). 

If you are interested in requesting features or wish to report a bug, please post a GitHub issue prefixed with the tag `[Feature Request]` and `[Bug]`, respectively.

_________________________________


#### *Soothsayer* in the wild:
_________________________________
* Espinoza JL+, Dupont CL+, O’Rourke A, Beyhan S, Morales P, et al. (2021) Predicting antimicrobial mechanism-of-action from transcriptomes: A generalizable explainable artificial intelligence approach. PLOS Computational Biology 17(3): e1008857. [doi:10.1371/journal.pcbi.1008857](https://doi.org/10.1371/journal.pcbi.1008857)


* Yu Imai, Kirsten J. Meyer, Akira Iinishi, Quentin Favre-Godal, Robert Green, Sylvie Manuse, Mariaelena Caboni, Miho Mori, Samantha Niles, Meghan Ghiglieri, Chandrashekhar Honrao, Xiaoyu Ma, Jason Guo, Alexandros Makriyannis, Luis Linares-Otoya, Nils Böhringer, Zerlina G. Wuisan, Hundeep Kaur, Runrun Wu, Andre Mateus, Athanasios Typas, Mikhail M. Savitski, Josh L. Espinoza, Aubrie O’Rourke, Karen E. Nelson, Sebastian Hiller, Nicholas Noinaj, Till F. Schäberle, Anthony D’Onofrio & Kim Lewis. (2019). A new antibiotic selectively kills Gram-negative pathogens. Nature. [doi:10.1038/s41586-019-1791-1](https://www.nature.com/articles/s41586-019-1791-1). 

* Espinoza JL, Shah N, Singh S, Nelson KE, Dupont CL. Applications of weighted association networks applied to compositional data in biology. Environ Microbiol. 2020 May 20;. [doi: 10.1111/1462-2920.15091](https://sfamjournals.onlinelibrary.wiley.com/doi/full/10.1111/1462-2920.15091). PubMed PMID: 32436334.

* Santoro EP, Borges RM, Espinoza JL, Freire M, Messias CSMA, Villela HDM, Pereira LM, Vilela CLS, Rosado JG, Cardoso PM, Rosado PM, Assis JM, Duarte GAS, Perna G, Rosado AS, Macrae A, Dupont CL, Nelson KE, Sweet MJ, Voolstra CR, Peixoto RS. Coral microbiome manipulation elicits metabolic and genetic restructuring to mitigate heat stress and evade mortality. Sci Adv. 2021 Aug 13;7(33):eabg3088. [doi: 10.1126/sciadv.abg3088](https://advances.sciencemag.org/content/7/33/eabg3088). PMID: 34389536.

* Nabwera HM+, Espinoza JL+, Worwui A, Betts M, Okoi C, Sesay AK et al. Interactions between fecal gut microbiome, enteric pathogens, and energy regulating hormones among acutely malnourished rural Gambian children. EBioMedicine 2021; 73: 103644. [doi:10.1016/j.ebiom.2021.103644](https://doi.org/10.1016/j.ebiom.2021.103644)

* Espinoza JL, Dupont CL. VEBA: a modular end-to-end suite for in silico recovery, clustering, and analysis of prokaryotic, microeukaryotic, and viral genomes from metagenomes. BMC Bioinformatics. 2022 Oct 12;23(1):419. [doi: 10.1186/s12859-022-04973-8](https://doi.org/10.1186/s12859-022-04973-8). PMID: 36224545.

<img src="logo/soothsayer_wide.png" width=200>


